<?php

namespace ApplicationTest;

/**
 * Description of ManifestBuilderTest
 *
 * @author Vladimir Guloyants <vladimir@guloyants.net>
 * @package 
 * @copyright (c) 2014 Vladimir Guloyants
 */
class ManifestBuilderTest extends \PHPUnit_Framework_TestCase {

    /**
     * @var \Application\ManifestBuilder | null
     */
    protected $manifestBuilder = null;

    public static function setUpBeforeClass() {
        
        require realpath(__DIR__ . DIRECTORY_SEPARATOR
                        . '..' . DIRECTORY_SEPARATOR
                        . '..' . DIRECTORY_SEPARATOR
                        . 'src' . DIRECTORY_SEPARATOR
                        . 'Application' . DIRECTORY_SEPARATOR
                        . 'ManifestBuilder.php');
    }

    public function setUp() {
        $this->manifestBuilder = new \ManifestBuilder();
    }

    public function testThrowsExceptionOnNonExistingResource() {
        $this->setExpectedException('\Exception');
        $this->manifestBuilder->addResources('resource', 'nonexistingsection');
    }

    public function testSetDebugModeBooleanCast() {
        $this->assertTrue($this->manifestBuilder->setDebugMode(1)->getDebugMode());
        $this->assertTrue($this->manifestBuilder->setDebugMode('true')->getDebugMode());
        $this->assertFalse($this->manifestBuilder->setDebugMode(0)->getDebugMode());
        $this->assertFalse($this->manifestBuilder->setDebugMode('')->getDebugMode());
    }

    public function testRecursiveFileWalk() {
        $this->manifestBuilder->addResourcesFromDirectory($this->getDataDir(), 'cache');
        $this->assertEquals(10, count($this->manifestBuilder->getResourcesBySection()));
    }

    protected function getDataDir() {
        return realpath(__DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'public' . DIRECTORY_SEPARATOR . 'img');
    }

}
